jquery.multi-select.js - Documentation
Description: Documentation page for jquery.multi-select.js jquery plugin

Download

# jquery.multi-select.js

## Options

option | default | description
--- | --- | ---
afterSelect | function() {} | Function to call after one option is selected.
afterDeselect | function() {} | Function to call after one option is deselected.
selectableHeader | null | Text or HTML to display on the selectable container.
selectedHeader | null | Text or HTML to display on the selected container.
disabledClass | 'disabled' | CSS class for disabled items.
emptyArray | false | Will return an empty array instead of null when nothing is selected. Warning: It is not the standard multiselect behavior, if set to true your code will not remains unobstrusive.

## Methods

You must init the multiple select with $('#my-select').multiSelect() before calling one of the following methods.

method | params | example
--- | --- | ---
select | value (String) | $('#my-select').multiSelect('select', 'fr');
deselect | value (String) | $('#my-select').multiSelect('deselect', 'fr');
select_all | visible (optional Boolean) | $('#my-select').multiSelect('select_all', true); If visible set to true, it will select only visible items on te selectable list. Otherwise it will also select hidden items.
deselect_all | - | $('#my-select').multiSelect('deselect_all');